@@ -15,10 +15,10 @@ async def coromask(coro, args, kwargs, fargs):
 
     :returns: a result, is a list of the elements for future argument
     """
-    msg = ("Coromask args %s, kwargs %s, in coro %s" %
-           (args, kwargs, coro))    
     try:
         _in = args
+        msg = ("Coromask args %s, kwargs %s, in coro %s" %
+               (args, kwargs, coro))
         obtained = await coro(*args, **kwargs)
         if isinstance(obtained, Exception):
             raise Exception()
@@ -41,7 +41,11 @@ def renew(task, coro, fargs, *args, **kwargs):
     :param args: the unpacked list of extra arguments
     """
     if task.exception():
-        raise task.result()
+        try:
+            raise task.result()
+        except asyncio.CancelledError as ce:
+            print("Task cancelled",ce)
+            raise ce
     else:
         try:
             result = task.result()
@@ -53,28 +57,7 @@ def renew(task, coro, fargs, *args, **kwargs):
         except Exception as e:
             print("Resultado", result, task, coro, fargs)
             print("Excepcion en renew", e)
-
-
-def renew_quamash(task, coro, fargs, loop, *args, **kwargs):
-    """
-    A simple function who manages the scheduled task and set the
-    renew of the task.
-    The same as *renew* but it can be used with different *event loop* like *quamash* for *qt*
-
-    :param task: is a Future initialized coroutine but not executed yet
-    :param coro: is the corutine to renew when the first is finished
-    :param fargs: the function to process input/output
-    :param loop: a different event loop from *asyncio*
-    :param args: the unpacked list of extra arguments
-
-    """
-    if task.exception():
-        raise task.result()
-    else:
-        result = task.result()
-        task = loop.create_task(coromask(coro, result, fargs))
-        task.add_done_callback(functools.partial(
-            renew_quamash, task, coro, fargs, loop))
+            raise e
 
 
 def simple_fargs(_in, obtained):
